@@ -7,8 +7,10 @@ NOW=NOW.strftime('%Y-%m-%d %H:%M:%S')
 def is_numeric(x):
 	try:float(x);return True
 	except:return False
-def now(x=None):#x can be int means convert timestamp to string,or sting means convert string to timestamp
-	if x is None:return int(datetime.datetime.now().timestamp())
+def now(x=None):#x=micro return microsecond;x=str return string;x is int means convert timestamp to string;x is sting means convert string to timestamp
+	if not x:return int(datetime.datetime.now().timestamp())
+	elif x=='micro':return datetime.datetime.now().timestamp()
+	elif x=='str':return datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
 	elif isinstance(x,int):return datetime.datetime.fromtimestamp(x).strftime('%Y-%m-%d %H:%M:%S')
 	else:
 		try: import dateutil.parser;return int(dateutil.parser.parse(x).timestamp())
@@ -26,6 +28,11 @@ def print(*a,func=None,time='%m/%d %H:%M:%S',pretty=False,**s):
 			pprint.pprint(x)
 	else:
 		builtins.print(*a,**s)
+def split_str(strs,num=1):
+	_=[]
+	for x in range(math.ceil(len(strs)/num)):
+		_.append(strs[x*num:x*num+num])
+	return _
 def diff(a,b):
 	diff={}
 	for x in a:
@@ -38,7 +45,7 @@ def md5(x):import hashlib;hl = hashlib.md5();hl.update(x.encode('utf-8') if isin
 def bin2hex(x):import binascii;return binascii.hexlify(x.encode('utf-8') if isinstance(x,str) else x);
 def base64_encode(x):import base64;return base64.b64encode(x) if isinstance(x,bytes) else base64.b64encode(x.encode('utf-8'))
 def base64_decode(x):import base64;return base64.b64decode(x)
-def log(*x,path=None):
+def log(*x,path=None):#已经带有时间
 	if path is None:
 		path='/tmp/frank.log' if os.path.exists('/tmp') else './FPC.log'
 	with open(path,'a',encoding='utf-8') as f:
@@ -99,7 +106,6 @@ class mysql(object):
 		return data
 	def add(self,dicts,table=None):
 		'''table is optional,dicts can be list or dict'''
-		if not dicts:return
 		if not isinstance(table,str):
 			if table is None:
 				table=self.table
@@ -115,7 +121,6 @@ class mysql(object):
 		return self.execute(r''' insert `%s`(%s) values%s '''%(table,key,values[:-1]))
 	def update(self,where,data,table=None):
 		'''where can be str or dict'''
-		if not data:return
 		if table is None:
 			table=self.table
 		if isinstance(where,dict) : where=self._split_dict(where,'and')
@@ -136,22 +141,21 @@ class redis(object):
 		self.redis=redis.StrictRedis(host=host, port=port, db=db,decode_responses=True)
 	def __getattr__(self,attr):
 		return getattr(self.redis,attr)
-def process(target,is_thread=True,join=False,num=1,sleep=None,**args):
-	if isinstance(target,str):#args:target,[sync]
+def process(target,is_thread=True,join=False,num=1,sleep=None,**args):#args[['',''],]
+	if isinstance(target,str):#args:target,[sync=True]
 		import subprocess
 		proc=subprocess.Popen(target,stdin=subprocess.PIPE,stdout=subprocess.PIPE,stderr=subprocess.PIPE,shell=True);
-		return proc.communicate() if args.get('sync') else None
+		return proc.communicate() if args.get('sync',True) else proc
 	pros=[]
 	if 'args' in args:
-		if isinstance(args['args'],list):
-			args_list=args['args']
-			if num==1:num=len(args_list)
-		else:args_list=[args['args']]*num
+		assert isinstance(args['args'],list)
+		args_list=args['args']
+		num=len(args_list)
 	if is_thread:
 		import threading
 		for x in range(num):
 			if 'args' in args:
-				args['args']=args_list[x] if isinstance(args_list[x],(tuple,list)) else [args_list[x]]
+				args['args']=args_list[x]
 			pros.append(threading.Thread(target=target,**args))
 			pros[-1].start()
 			if sleep:time.sleep(sleep)
